package top.r3944realms.lib39.core.compat;

import net.minecraftforge.eventbus.api.IEventBus;

/**
 * The interface Compat.
 */
public interface IForgeCompat extends ICompat {
    /**
     * Add common game listener.
     *
     * @param gameBus the game bus
     */
    default void addCommonGameListener(IEventBus gameBus) {
        // 实现通用游戏事件监听器添加逻辑
    }

    /**
     * Add common mod listener.
     *
     * @param modBus the mod bus
     */
    default void addCommonModListener(IEventBus modBus) {
        // 实现通用模组事件监听器添加逻辑
    }

    /**
     * Add client game listener.
     *
     * @param gameBus the game bus
     */
    default void addClientGameListener(IEventBus gameBus) {
        // 实现客户端游戏事件监听器添加逻辑
    }

    /**
     * Add client mod listener.
     *
     * @param modBus the mod bus
     */
    default void addClientModListener(IEventBus modBus) {
        // 实现客户端模组事件监听器添加逻辑
    }

    /**
     * Add server game listener.
     *
     * @param gameBus the game bus
     */
    default void addServerGameListener(IEventBus gameBus) {
        // 实现服务端游戏事件监听器添加逻辑
    }

    /**
     * Add server mod listener.
     *
     * @param modBus the mod bus
     */
    default void addServerModListener(IEventBus modBus) {
        // 实现服务端模组事件监听器添加逻辑
    }
}
